# @authors: Andrew P. Craig
# @email: apc53@cam.ac.uk
# @date: 2017/10/09
# @copyright: MIT License

# HLBPlotFigures.py uses a different figure naming scheme from that used in the paper,
# so this script converts between them.

import shutil, sys, os

if len(sys.argv) < 2:
    print("The first argument is the ID of the figures to be cleaned.")
else:
    ID = str(sys.argv[1])
    sourcePrefix = os.path.join('..', 'HLBFigs', ID + '_Fig')
    destPrefix = os.path.join('..', 'HLBFigs', 'Paper', 'Fig_')
    suffix = '.png'
    sourceDest = {  '2_Old':'2', # SECIR time courses.
                    '3_Old':'3', # Actual, detectable prev.
                    '4_Old':'4', # AUC, yield time courses.
                    '5_Old':'5', # 2 x 1 boxplots.
                    '8_Old':'S1', # Tree grids over time.
                    '9_Old':'S2', # 100% detection efficiency.
                    '6_Old':'S3', # 2 x 2 boxplots.
                    '11_Old':'S4', # SECIR of sensitivity sims.
                    '10_Old':'S5', # Actual, detectable prev of sensitivity sims.
                    '12_Old':'S6', # Boxplots, sensitivity.
                    '2_Young':'S7', # SECIR time courses.
                    '3_Young':'S8', # Actual, detectable prev.
                    '4_Young':'S9', # AUC, yield time courses.
                    # Note: No 8_Young figure.
                    '5_Young':'S10', # 2 x 1 boxplots.
                    '9_Young':'S11', # 100% detection efficiency.
                    '6_Young':'S12', # 2 x 2 boxplots.
                    '11_Young':'S13', # SECIR of sensitivity sims.
                    '10_Young':'S14', # Actual, detectable prev of sensitivity sims.
                    '12_Young':'S15'} # Boxplots, sensitivity.
    for source in sourceDest:
        sourceFull = sourcePrefix + source + suffix
        destFull = destPrefix + sourceDest[source] + suffix
        try:
            shutil.copyfile(sourceFull, destFull)
            print("Copied " + sourceFull + " to " + destFull)
        except IOError as e:
            print("Tried but failed to copy " + sourceFull + " to " + destFull)
