//---------------------------------------------------------------------------//
// Copyright (c) 2017 Matthew Parry & Andrew P. Craig
//
// Distributed under The MIT License (MIT)
// See accompanying file LICENSE.txt
//---------------------------------------------------------------------------//

#pragma once

#include "utils.hpp"
#include "random_numbers.hpp"
#include <cmath>

// Severity parameters.
const double s0_by_age_category[] = {0.2,0.1,0.05,0.025}; // Corresponding to tree ages 0-3, 3-5, 5-10, 10+.
const double rL_by_age_category[] = {3.68,1.84,0.92,0.69}; // Corresponding to tree ages 0-3, 3-5, 5-10, 10+.
// Yield parameters.
const double yield_b[] = {1.95,1.94,1.66,1.85}; // Corresponding to seasonalities: early, mid-season, late, combined data.
const int seasonality = 3;

double get_severity_s0(double age) {
	double severity_s0 = -999;
	if(age > 10) {
		severity_s0 = s0_by_age_category[3];
	}
	else {
		if(age > 5) {
			severity_s0 = s0_by_age_category[2];
		}
		else {
			if(age > 3) {
				severity_s0 = s0_by_age_category[1];
			}
			else {
				severity_s0 = s0_by_age_category[0];
			}
		}
	}
	return severity_s0;
}

double get_severity_rL(double age) {
	double severity_rL = -999;
	if(age > 10) {
		severity_rL = rL_by_age_category[3];
	}
	else {
		if(age > 5) {
			severity_rL = rL_by_age_category[2];
		}
		else {
			if(age > 3) {
				severity_rL = rL_by_age_category[1];
			}
			else {
				severity_rL = rL_by_age_category[0];
			}
		}
	}
	return severity_rL;
}

double calculate_yield(int N,double *E,double *R,double *severity_s0,double *severity_rL,double time_of_calculation,bool R_trees_contribute_to_yield,int iGroup,timeline *T,double *yield_variation_param)
{
	double total_yield = 0;
	double severity;
	double base_yield;
	// Find total yield of all trees.
	for(int iTree = 0; iTree < N; iTree++) {
		if(T[iTree].group == iGroup) { // Only include trees in the group in question.
			if(R[iTree] <= time_of_calculation && !R_trees_contribute_to_yield) {
				// If tree is R, yield for tree is 0, so do nothing.
			}
			else {
				if(E[iTree] <= time_of_calculation) {
					// If tree is E, I, D, yield is calculated according to severity.
					severity = 1 / (1 + ((1 / severity_s0[iTree]) - 1)*exp((-severity_rL[iTree] * (time_of_calculation - E[iTree]))));
					// Calculate base yield, with no variability applied.
					base_yield = exp(-1 * yield_b[seasonality] * severity);
				}
				else {
					// Tree is S, and base yield is 1.
					base_yield = 1;
				}
				// Multiply base yield by individual tree yield variation parameter.
				total_yield += yield_variation_param[iTree] * base_yield;
			}
		}
	}
	return total_yield;
}

double calculate_yield_if_uninfected(int N,int iGroup,timeline *T,double *yield_variation_param){
	double total_yield = 0;
	double yield_from_iTree;
	double base_yield = 1; // Because assuming all trees uninfected.
	// Find total yield of all trees.
	for(int iTree = 0; iTree < N; iTree++) {
		if(T[iTree].group == iGroup) { // Only include trees in the group in question.
			// Multiply base yield by individual tree yield variation parameter.
			yield_from_iTree = yield_variation_param[iTree] * base_yield;
			total_yield += yield_from_iTree;
		}
	}
	return total_yield;
}