# Instructions for running simulations for Huanglongbing paper of Craig et al.

## Overview

The accompanying files can be used to reproduce the results of the study of the citrus disease Huanglongbing by
Andrew P Craig, Nik J. Cunniffe, Matthew Parry, Francisco F. Laranjeira and Christopher A. Gilligan, appearing in the Journal of Applied Ecology. That is, these files can be used to rerun the study's simulations and, using the output thereof, produce figures identical to those in the paper (excepting possible minor formatting differences).

Directories:

- HLBParrySoln: Contains the C++ code for the simulator.
- HLBManager: Contains the Python code to manage the simulations and produce the figures.
- HLBAppsAndInput: Contains data files used by the simulator.
- HLBSims: Contains the files that determine which simulations to run. Simulation result files will appear here.
- HLBFigs: Initially empty. Figures will be saved here.

## Setup

### Requirements

- g++ C++ compiler
- Boost C++ libraries
- Python 2.7
- virtualenv
- imagemagick

### Simulator

Follow the instructions in HLBParrySoln/README.txt to compile the simulator.

### Simulation manager

Use virtualenv to install the required versions of the required Python packages:

```
cd HLBManager
virtualenv env
source env/bin/activate
pip install --upgrade pip
pip install -r requirements.txt
```

## Running the simulations

The files that specify what simulations need to be run are:

```
HLBSims/ID_20171007132821/summary_ID_20171007132821.csv
HLBSims/ID_20171008221657/summary_ID_20171008221657.csv
```

To set up the required files to run these simulations (while in HLBManager):

```
python HLBMakeJobs.py 20171007132821
python HLBMakeJobs.py 20171008221657
```

Each of these will produce instructions on how to start the simulations running. They can be run locally (although this will take a very long time), or on a cluster using HTCondor. Running the simulations using cluster software other than HTCondor will require modifying the code.

The jobs produced by the above will have their own IDs.

## Creating the figures

Once the simulations have finished running, generate the figures using the following code. The IDs produced by the above calls to HLBMakeJobs.py should be used.

```
python HLBPlotFigures.py [ID from jobs produced from 20171007132821]  2 9
python HLBPlotFigures.py [ID from jobs produced from 20171008221657]  10 12
```

The figures produced use a different naming scheme to that of the paper, so to make them consistent run (while in HLBManager):

```
python HLBCleanFigureNames.py [ID from jobs produced from 20171007132821]
python HLBCleanFigureNames.py [ID from jobs produced from 20171008221657]
```

Figures with names consistent with those in the paper will now be in HLBFigs/Paper/ .
